@@ -3,7 +3,7 @@
 set -ex
 
 TESTDIR=$(mktemp -d )
-TESTCODE=$(readlink -f tests/014_ilistdump_test.c)
+TESTCODE=$(readlink -f cowdancer-ilistdump.c)
 
 (
     cd ${TESTDIR}
@@ -17,13 +17,11 @@ TESTCODE=$(readlink -f tests/014_ilistdump_test.c)
     dd if=/dev/zero of=1/e bs=512 count=2
 
     cd 1 
-    find -links +1 -type f -printf "%D %i\n" | sort +2 -n > ../mylist.1
-    cow-shell echo hello
+    find -links +1 -type f -printf "%D %i\n" | sort -k 2 -n > ../mylist.1
+    cow-shell "${TESTCODE}" ${TESTDIR}/1/.ilist | sort -k 2 -n > ${TESTDIR}/mylist.2
 )
 RET=$?
 
-$TESTCODE < ${TESTDIR}/1/.ilist | sort +2 -n > ${TESTDIR}/mylist.2
-
 diff -u ${TESTDIR}/mylist.1 ${TESTDIR}/mylist.2
 
 rm -rf ${TESTDIR}
