@@ -11,6 +11,11 @@ if [[ $(uname -mn ) != "dancer64 x86_64" ]]; then
     exit 0;
 fi
 
+if [[ "$PBCURRENTCOMMANDLINEOPERATION" = build ]]; then
+    echo 'skip this test'
+    exit 0;
+fi
+
 set -ex
 
 if [ ! -x /usr/sbin/pbuilder ]; then
@@ -19,7 +24,7 @@ if [ ! -x /usr/sbin/pbuilder ]; then
 fi
 
 sudo rm -rf /var/cache/pbuilder/base-test.cow
-sudo cowbuilder --create --hookdir /usr/share/doc/pbuilder/examples/workaround/ --debootstrapopts --debug --basepath /var/cache/pbuilder/base-test.cow
+sudo cowbuilder --create --hookdir /usr/share/doc/pbuilder/examples/workaround/ --debootstrap debootstrap --debootstrapopts --verbose --basepath /var/cache/pbuilder/base-test.cow
 sudo cowbuilder --update --hookdir /usr/share/doc/pbuilder/examples/workaround/ --basepath /var/cache/pbuilder/base-test.cow
 pdebuild --pbuilder cowbuilder -- --basepath /var/cache/pbuilder/base-test.cow
 
