@@ -1,6 +1,16 @@
 #!/bin/bash
 set -x
 
+if [[ $(uname -mn ) != "dancer64 x86_64" ]]; then
+    echo 'skip this test'
+    exit 0;
+fi
+
+if [[ "$PBCURRENTCOMMANDLINEOPERATION" = build ]]; then
+    echo 'skip this test'
+    exit 0;
+fi
+
 : > tests/log/901_test_pbuilder_create_distributions.log
 
 FAIL=n
@@ -9,7 +19,7 @@ for DEBOOTSTRAP in debootstrap cdebootstrap; do
     for DISTRIBUTION in etch sid; do
 	sudo rm -rf /var/cache/pbuilder/base-test.cow
 	if [ $DEBOOTSTRAP = cdebootstrap ]; then
-	    DEBUG="--debootstrapopts --debug"
+	    DEBUG="--debootstrapopts --verbose"
 	else
 	    DEBUG=
 	fi
